<?php

return [
    'Names' => [
        'aa' => 'អាហ្វារ',
        'ab' => 'អាប់ខាហ៊្សាន',
        'ace' => 'អាកហ៊ីនឺស',
        'ada' => 'អាដេងមី',
        'ady' => 'អាឌីហ្គី',
        'ae' => 'អាវេស្ថាន',
        'af' => 'អាហ្វ្រិកាន',
        'agq' => 'អាហ្គីម',
        'ain' => 'អាយនូ',
        'ak' => 'អាកាន',
        'ale' => 'អាលូត',
        'alt' => 'អាល់តៃខាងត្បូង',
        'am' => 'អាំហារិក',
        'an' => 'អារ៉ាហ្គោន',
        'ann' => 'អូបូឡូ',
        'anp' => 'អាហ្គីកា',
        'ar' => 'អារ៉ាប់',
        'arn' => 'ម៉ាពូឈី',
        'arp' => 'អារ៉ាប៉ាហូ',
        'ars' => 'អារ៉ាប់ណាឌី',
        'as' => 'អាសាមីស',
        'asa' => 'អាស៊ូ',
        'ast' => 'អាស្ទូរី',
        'atj' => 'អាទិកាម៉េក',
        'av' => 'អាវ៉ារីក',
        'awa' => 'អាវ៉ាឌី',
        'ay' => 'អីម៉ារ៉ា',
        'az' => 'អាស៊ែបៃហ្សង់',
        'ba' => 'បាស្គៀ',
        'ban' => 'បាលី',
        'bas' => 'បាសា',
        'be' => 'បេឡារុស',
        'bem' => 'បេមបា',
        'bez' => 'បេណា',
        'bg' => 'ប៊ុលហ្ការី',
        'bgn' => 'បាឡូជីខាងលិច',
        'bho' => 'បូចពូរី',
        'bi' => 'ប៊ីស្លាម៉ា',
        'bin' => 'ប៊ីនី',
        'bla' => 'ស៊ីកស៊ីកា',
        'bm' => 'បាម្បារា',
        'bn' => 'បង់ក្លាដែស',
        'bo' => 'ទីបេ',
        'br' => 'ប្រ៊ីស្តុន',
        'brx' => 'បូដូ',
        'bs' => 'បូស្នី',
        'bug' => 'ប៊ុកហ្គី',
        'byn' => 'ប្ល៊ីន',
        'ca' => 'កាតាឡាន',
        'cay' => 'ខាយូហ្កា',
        'ccp' => 'ចាក់ម៉ា',
        'ce' => 'ឈីឆេន',
        'ceb' => 'ស៊ីប៊ូអាណូ',
        'cgg' => 'ឈីហ្កា',
        'ch' => 'ឈីម៉ូរ៉ូ',
        'chk' => 'ឈូគី',
        'chm' => 'ម៉ារី',
        'cho' => 'ឆុកតាវ',
        'chp' => 'ឈីប៉េវ៉ាយអិន',
        'chr' => 'ឆេរូគី',
        'chy' => 'ឈីយីនី',
        'ckb' => 'ឃើដភាគកណ្តាល',
        'clc' => 'ឈីលកូទីន',
        'co' => 'កូស៊ីខាន',
        'crg' => 'មីឈីហ្វ',
        'crj' => 'គ្រីខាងកើត​ប៉ែកខាងត្បូង',
        'crk' => 'គ្រីតំបន់វាលរាប',
        'crl' => 'គ្រីខាងកើត​ប៉ែកខាងជើង',
        'crm' => 'មូសគ្រី',
        'crr' => 'អាល់ហ្គនខ្វៀន ខារ៉ូលីណា',
        'crs' => 'សេសេលវ៉ាគ្រីអូល (បារាំង)',
        'cs' => 'ឆែក',
        'csw' => 'គ្រីតំបន់ភក់ល្បាប់',
        'cu' => 'ឈើជស្លាវិក',
        'cv' => 'ឈូវ៉ាស',
        'cy' => 'វេល',
        'da' => 'ដាណឺម៉ាក',
        'dak' => 'ដាកូតា',
        'dar' => 'ដាចវ៉ា',
        'dav' => 'តៃតា',
        'de' => 'អាល្លឺម៉ង់',
        'dgr' => 'ដូគ្រីប',
        'dje' => 'ហ្សាម៉ា',
        'doi' => 'ដូហ្គ្រី',
        'dsb' => 'សូប៊ីក្រោម',
        'dua' => 'ឌួលឡា',
        'dv' => 'ទេវីហ៊ី',
        'dyo' => 'ចូឡាហ៊្វុនយី',
        'dz' => 'ដុងខា',
        'dzg' => 'ដាហ្សាហ្គា',
        'ebu' => 'អេមប៊ូ',
        'ee' => 'អ៊ីវ',
        'efi' => 'អ៊ីហ្វិក',
        'eka' => 'អ៊ីកាជុក',
        'el' => 'ក្រិក',
        'en' => 'អង់គ្លេស',
        'eo' => 'អេស្ពេរ៉ាន់តូ',
        'es' => 'អេស្ប៉ាញ',
        'et' => 'អេស្តូនី',
        'eu' => 'បាសខ៍',
        'ewo' => 'អ៊ីវ៉ុនដូ',
        'fa' => 'ភឺសៀន',
        'ff' => 'ហ្វ៊ូឡា',
        'fi' => 'ហ្វាំងឡង់',
        'fil' => 'ហ្វ៊ីលីពីន',
        'fj' => 'ហ៊្វីជី',
        'fo' => 'ហ្វារូស',
        'fon' => 'ហ្វ៊ុន',
        'fr' => 'បារាំង',
        'frc' => 'បារាំងកាហ្សង់',
        'frr' => 'ហ្វ្រ៊ីសៀន​ខាងជើង',
        'fur' => 'ហ៊្វ្រូលាន',
        'fy' => 'ហ្វ្រីស៊ានខាងលិច',
        'ga' => 'អៀរឡង់',
        'gaa' => 'ហ្គា',
        'gag' => 'កាគូស',
        'gd' => 'ស្កុតហ្កែលិគ',
        'gez' => 'ជីស',
        'gil' => 'ហ្គីលបឺទ',
        'gl' => 'ហ្កាលីស្យាន',
        'gn' => 'ហ្គូរ៉ានី',
        'gor' => 'ហ្គូរុនតាឡូ',
        'gsw' => 'អាល្លឺម៉ង (ស្វីស)',
        'gu' => 'ហ្គុយ៉ារ៉ាទី',
        'guz' => 'ហ្គូស៊ី',
        'gv' => 'មេន',
        'gwi' => 'ហ្គីចឈីន',
        'ha' => 'ហូសា',
        'hai' => 'ហៃដា',
        'haw' => 'ហាវ៉ៃ',
        'hax' => 'ហៃដាខាងត្បូង',
        'he' => 'ហេប្រឺ',
        'hi' => 'ហិណ្ឌី',
        'hil' => 'ហ៊ីលីហ្គេណុន',
        'hmn' => 'ម៉ុង',
        'hr' => 'ក្រូអាត',
        'hsb' => 'សូប៊ីលើ',
        'ht' => 'ហៃទី',
        'hu' => 'ហុងគ្រី',
        'hup' => 'ហ៊ូប៉ា',
        'hur' => 'ហាល់កូម៉េឡេម',
        'hy' => 'អាមេនី',
        'hz' => 'ហឺរីរ៉ូ',
        'ia' => 'អ៊ីនធើលីង',
        'iba' => 'អ៊ីបាន',
        'ibb' => 'អាយប៊ីប៊ីអូ',
        'id' => 'ឥណ្ឌូណេស៊ី',
        'ig' => 'អ៊ីកបូ',
        'ii' => 'ស៊ីឈាន់យី',
        'ikt' => 'អ៊ីនុកទីទុត​កាណាដា​ប៉ែកខាងលិច',
        'ilo' => 'អ៊ីឡូកូ',
        'inh' => 'អ៊ិនហ្គូស',
        'io' => 'អ៊ីដូ',
        'is' => 'អ៊ីស្លង់',
        'it' => 'អ៊ីតាលី',
        'iu' => 'អ៊ីនុកទីទុត',
        'ja' => 'ជប៉ុន',
        'jbo' => 'លុចបាន',
        'jgo' => 'ងុំបា',
        'jmc' => 'ម៉ាឆាំ',
        'jv' => 'ជ្វា',
        'ka' => 'ហ្សក​ហ្ស៊ី',
        'kab' => 'កាប៊ីឡេ',
        'kac' => 'កាឈីន',
        'kaj' => 'ជូ',
        'kam' => 'កាំបា',
        'kbd' => 'កាបាឌៀ',
        'kcg' => 'យ៉ាប់',
        'kde' => 'ម៉ាកូនដេ',
        'kea' => 'កាប៊ូវឺឌៀនូ',
        'kfo' => 'គូរូ',
        'kgp' => 'ខាងហ្កេង',
        'kha' => 'កាស៊ី',
        'khq' => 'គុយរ៉ាឈីនី',
        'ki' => 'គីគូយូ',
        'kj' => 'គូនយ៉ាម៉ា',
        'kk' => 'កាហ្សាក់',
        'kkj' => 'កាកូ',
        'kl' => 'កាឡាលលីស៊ុត',
        'kln' => 'កាលែនជីន',
        'km' => 'ខ្មែរ',
        'kmb' => 'គីមប៊ុនឌូ',
        'kn' => 'ខាណាដា',
        'ko' => 'កូរ៉េ',
        'koi' => 'គូមីភឹមយ៉ាគ',
        'kok' => 'គុនកានី',
        'kpe' => 'គ្លីប',
        'kr' => 'កានូរី',
        'krc' => 'ការ៉ាឆាយបាល់កា',
        'krl' => 'ការីលា',
        'kru' => 'គូរូក',
        'ks' => 'កាស្មៀរ',
        'ksb' => 'សាមបាឡា',
        'ksf' => 'បាហ្វៀ',
        'ksh' => 'កូឡូញ',
        'ku' => 'ឃឺដ',
        'kum' => 'គូមីគ',
        'kv' => 'កូមី',
        'kw' => 'កូនីស',
        'kwk' => 'ក្វាក់វ៉ាឡា',
        'ky' => '​កៀហ្ស៊ីស',
        'la' => 'ឡាតំាង',
        'lad' => 'ឡាឌីណូ',
        'lag' => 'ឡានហ្គី',
        'lb' => 'លុចសំបួ',
        'lez' => 'ឡេសហ្គី',
        'lg' => 'ហ្កាន់ដា',
        'li' => 'លីមប៊ូស',
        'lij' => 'លីគូរី',
        'lil' => 'លីលលូអេត',
        'lkt' => 'ឡាកូតា',
        'ln' => 'លីនកាឡា',
        'lo' => 'ឡាវ',
        'lou' => 'ក្រេអូល លូអ៊ីស៊ីអាណា',
        'loz' => 'ឡូហ្ស៊ី',
        'lrc' => 'លូរីខាងជើង',
        'lsm' => 'សាមៀ',
        'lt' => 'លីទុយអានី',
        'lu' => 'លូបាកាតានហ្គា',
        'lua' => 'លូបាលូឡា',
        'lun' => 'លុនដា',
        'luo' => 'លូអូ',
        'lus' => 'មីហ្សូ',
        'luy' => 'លូយ៉ា',
        'lv' => 'ឡាតវី',
        'mad' => 'ម៉ាឌូរីស',
        'mag' => 'ម៉ាហ្គាហ៊ី',
        'mai' => 'ម៉ៃធីលី',
        'mak' => 'ម៉ាកាសា',
        'mas' => 'ម៉ាសៃ',
        'mdf' => 'មុខសា',
        'men' => 'មេនឌី',
        'mer' => 'មេរូ',
        'mfe' => 'ម៉ូរីស៊ីន',
        'mg' => 'ម៉ាឡាហ្គាស៊ី',
        'mgh' => 'ម៉ាកគូវ៉ាមីតូ',
        'mgo' => 'មេតា',
        'mh' => 'ម៉ាស់សល',
        'mi' => 'ម៉ោរី',
        'mic' => 'មិកមេក',
        'min' => 'មីណាងកាប៊ូ',
        'mk' => 'ម៉ាសេដូនី',
        'ml' => 'ម៉ាឡាយ៉ាឡាម',
        'mn' => 'ម៉ុងហ្គោលី',
        'mni' => 'ម៉ានីពូរី',
        'moe' => 'អ៊ីននូអៃមុន',
        'moh' => 'ម៊ូហាគ',
        'mos' => 'មូស៊ី',
        'mr' => 'ម៉ារ៉ាធី',
        'ms' => 'ម៉ាឡេ',
        'mt' => 'ម៉ាល់តា',
        'mua' => 'មុនដាង',
        'mus' => 'គ្រីក',
        'mwl' => 'មីរ៉ានដេស',
        'my' => 'ភូមា',
        'myv' => 'អឺហ្ស៊ីយ៉ា',
        'mzn' => 'ម៉ាហ្សានដឺរេនី',
        'na' => 'ណូរូ',
        'nap' => 'នាប៉ូលីតាន',
        'naq' => 'ណាម៉ា',
        'nb' => 'ន័រវែស បុកម៉ាល់',
        'nd' => 'នេបេលេខាងជើង',
        'nds' => 'អាល្លឺម៉ង់ក្រោម',
        'ne' => 'នេប៉ាល់',
        'new' => 'នេវ៉ាវី',
        'ng' => 'នុនហ្គា',
        'nia' => 'នីអាស',
        'niu' => 'នូអៀន',
        'nl' => 'ហូឡង់',
        'nmg' => 'ក្វាស្យូ',
        'nn' => 'ន័រវែស នីនូស',
        'nnh' => 'ងៀមប៊ូន',
        'no' => 'ន័រវែស',
        'nog' => 'ណូហ្គៃ',
        'nqo' => 'នគោ',
        'nr' => 'នេប៊េលខាងត្បូង',
        'nso' => 'សូថូខាងជើង',
        'nus' => 'នូអ័រ',
        'nv' => 'ណាវ៉ាចូ',
        'ny' => 'ណានចា',
        'nyn' => 'ណានកូលេ',
        'oc' => 'អូសីតាន់',
        'ojb' => 'អូជីបវ៉ា​ប៉ែកពាយ័ព្យ',
        'ojc' => 'អូជីពវ៉ាកណ្ដាល',
        'ojs' => 'អូជីគ្រី',
        'ojw' => 'អូជីបវ៉ា​ខាងលិច',
        'oka' => 'អូកាណាហ្កាន',
        'om' => 'អូរ៉ូម៉ូ',
        'or' => 'អូឌៀ',
        'os' => 'អូស៊ីទិក',
        'pa' => 'បឹនជាពិ',
        'pag' => 'ភេនហ្គាស៊ីណាន',
        'pam' => 'ផាមភេនហ្គា',
        'pap' => 'ប៉ាប៉ៃមេនតូ',
        'pau' => 'ប៉ាលូអាន',
        'pcm' => 'ភាសាទំនាក់ទំនងនីហ្សេរីយ៉ា',
        'pis' => 'ពីជីន',
        'pl' => 'ប៉ូឡូញ',
        'pqm' => 'ម៉ាលីស៊ីត ប៉ាសាម៉ាខ្វូឌី',
        'prg' => 'ព្រូស៊ាន',
        'ps' => 'បាស្តូ',
        'pt' => 'ព័រទុយហ្គាល់',
        'qu' => 'ហ្គិកឈួ',
        'quc' => 'គីចឈី',
        'rap' => 'រ៉ាប៉ានូ',
        'rar' => 'រ៉ារ៉ូតុងហ្គាន',
        'rhg' => 'រ៉ូហ៊ីងយ៉ា',
        'rm' => 'រ៉ូម៉ង់',
        'rn' => 'រុណ្ឌី',
        'ro' => 'រូម៉ានី',
        'rof' => 'រុមបូ',
        'ru' => 'រុស្ស៊ី',
        'rup' => 'អារ៉ូម៉ានី',
        'rw' => 'គិនយ៉ាវ៉ាន់ដា',
        'rwk' => 'រ៉្វា',
        'sa' => 'សំស្ក្រឹត',
        'sad' => 'សានដាវី',
        'sah' => 'សាខា',
        'saq' => 'សាមបូរូ',
        'sat' => 'សាន់តាលី',
        'sba' => 'ងាំបេយ',
        'sbp' => 'សានហ្គូ',
        'sc' => 'សាឌីនា',
        'scn' => 'ស៊ីស៊ីលាន',
        'sco' => 'ស្កុត',
        'sd' => 'ស៊ីនឌី',
        'sdh' => 'ឃើដភាគខាងត្បូង',
        'se' => 'សាមីខាងជើង',
        'seh' => 'ស៊ីណា',
        'ses' => 'គុយរ៉ាបូរ៉ុស៊ីនី',
        'sg' => 'សានហ្គោ',
        'sh' => 'សឺបូក្រូអាត',
        'shi' => 'តាឈីលហ៊ីត',
        'shn' => 'សាន',
        'si' => 'ស្រីលង្កា',
        'sk' => 'ស្លូវ៉ាគី',
        'sl' => 'ស្លូវ៉ានី',
        'slh' => 'ឡាស៊ូតស៊ីតខាងត្បូង',
        'sm' => 'សាម័រ',
        'sma' => 'សាមីខាងត្បូង',
        'smj' => 'លូលីសាមី',
        'smn' => 'អ៊ីណារីសាមី',
        'sms' => 'ស្កុលសាមី',
        'sn' => 'សូណា',
        'snk' => 'សូនីនគេ',
        'so' => 'សូម៉ាលី',
        'sq' => 'អាល់បានី',
        'sr' => 'ស៊ែប',
        'srn' => 'ស្រាណានតុងហ្គោ',
        'ss' => 'ស្វាទី',
        'ssy' => 'សាហូ',
        'st' => 'សូថូខាងត្បូង',
        'str' => 'សាលីសស្ត្រេតស៍',
        'su' => 'ស៊ូដង់',
        'suk' => 'ស៊ូគូម៉ា',
        'sv' => 'ស៊ុយអែត',
        'sw' => 'ស្វាហ៊ីលី',
        'swb' => 'កូម៉ូរី',
        'syr' => 'ស៊ីរី',
        'ta' => 'តាមីល',
        'tce' => 'ថុចឆុនខាងត្បូង',
        'te' => 'តេលុគុ',
        'tem' => 'ធីមនី',
        'teo' => 'តេសូ',
        'tet' => 'ទីទុំ',
        'tg' => 'តាហ្ស៊ីគ',
        'tgx' => 'តាហ្គីស',
        'th' => 'ថៃ',
        'tht' => 'តាល់តាន',
        'ti' => 'ទីហ្គ្រីញ៉ា',
        'tig' => 'ធីហ្គ្រា',
        'tk' => 'តួកម៉េន',
        'tlh' => 'ឃ្លីនហ្គុន',
        'tli' => 'ថ្លីងហ្គីត',
        'tn' => 'ស្វាណា',
        'to' => 'តុងហ្គា',
        'tok' => 'តូគីប៉ូណា',
        'tpi' => 'ថុកពីស៊ីន',
        'tr' => 'ទួរគី',
        'trv' => 'តារ៉ូកូ',
        'ts' => 'សុងហ្គា',
        'tt' => 'តាតា',
        'ttm' => 'ថុចឆុនខាងជើង',
        'tum' => 'ទុមប៊ូកា',
        'tvl' => 'ទូវ៉ាលូ',
        'tw' => 'ទ្វី',
        'twq' => 'តាសាវ៉ាក់',
        'ty' => 'តាហ៊ីទី',
        'tyv' => 'ទូវីនៀ',
        'tzm' => 'តាម៉ាសាយអាត្លាសកណ្តាល',
        'udm' => 'អាត់មូដ',
        'ug' => 'អ៊ុយហ្គឺរ',
        'uk' => 'អ៊ុយក្រែន',
        'umb' => 'អាម់ប៊ុនឌូ',
        'ur' => 'អ៊ូរឌូ',
        'uz' => 'អ៊ូសបេគ',
        'vai' => 'វៃ',
        've' => 'វេនដា',
        'vec' => 'វេណេតូ',
        'vi' => 'វៀតណាម',
        'vo' => 'វូឡាពូក',
        'vun' => 'វុនចូ',
        'wa' => 'វ៉ាលូន',
        'wae' => 'វេលសឺ',
        'wal' => 'វ៉ូឡាយតា',
        'war' => 'វ៉ារេយ',
        'wbp' => 'វ៉ារីប៉ារី',
        'wo' => 'វូឡុហ្វ',
        'wuu' => 'អ៊ូចិន',
        'xal' => 'កាលមីគ',
        'xh' => 'ឃសា',
        'xog' => 'សូហ្គា',
        'yav' => 'យ៉ាងបេន',
        'ybb' => 'យេមបា',
        'yi' => 'យ៉ីឌីស',
        'yo' => 'យរូបា',
        'yrl' => 'ញីនហ្កាទូ',
        'yue' => 'កន្តាំង',
        'za' => 'ហ្សួង',
        'zgh' => 'តាម៉ាហ្សៃម៉ារ៉ុកស្តង់ដា',
        'zh' => 'ចិន',
        'zu' => 'ហ្សូលូ',
        'zun' => 'ហ្សូនី',
        'zza' => 'ហ្សាហ្សា',
    ],
    'LocalizedNames' => [
        'ar_001' => 'អារ៉ាប់ (ស្តង់ដារ)',
        'de_CH' => 'អាល្លឺម៉ង់ (ស្វ៊ីស)',
        'es_ES' => 'អេស្ប៉ាញ (អ៊ឺរ៉ុប)',
        'fa_AF' => 'ដារី',
        'fr_CH' => 'បារាំង (ស្វ៊ីស)',
        'nds_NL' => 'ហ្សាក់ស្យុងក្រោម',
        'nl_BE' => 'ផ្លាមីស',
        'pt_BR' => 'ព័រទុយហ្កាល់ (ប្រេស៊ីល)',
        'pt_PT' => 'ព័រទុយហ្គាល់ (អឺរ៉ុប)',
        'ro_MD' => 'ម៉ុលដាវី',
        'sw_CD' => 'កុងហ្គោស្វាហ៊ីលី',
        'zh_Hans' => 'ចិន​អក្សរ​កាត់',
        'zh_Hant' => 'ចិន​អក្សរ​ពេញ',
    ],
];
